#
# spec file for package python-numpy-doc
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define modname numpy
Name:           python-%{modname}-doc
%define docname numpydoc
Version:        1.8.0
Release:        4.31
%define docvers 0.4
Url:            http://sourceforge.net/projects/numpy
Summary:        Documentation for python-numpy
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Source:         %{modname}-%{version}.tar.gz
Patch0:         numpy-buildfix.patch
Patch1:         numpy-double-double-le.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  blas-devel
BuildRequires:  lapack-devel
BuildRequires:  python-Sphinx
BuildRequires:  python-devel
BuildRequires:  python-matplotlib
BuildRequires:  python-numpy-devel
BuildRequires:  python-numpydoc
BuildRequires:  texlive-latex
BuildRequires:  zip
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  gcc-fortran
%if 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%else
BuildArch:      noarch
%py_requires
%endif
%else
BuildRequires:  gcc-gfortran
%endif

%description
NumPy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays.  NumPy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type which also makes NumPy suitable for
interfacing with general-purpose data-base applications.

There are also basic facilities for discrete fourier transform,
basic linear algebra and random number generation.

This package provides the documentation for NumPy

%package html
Summary:        HTML documentation for python-%{modname}
Group:          Development/Libraries/Python
Recommends:     python-%{modname} = %{version}

%description html
NumPy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays.  NumPy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type which also makes NumPy suitable for
interfacing with general-purpose data-base applications.

There are also basic facilities for discrete fourier transform,
basic linear algebra and random number generation.

This package provides the HTML documentation for NumPy

%package pdf
Summary:        PDF documentation for python-%{modname}
Group:          Development/Libraries/Python
Recommends:     python-%{modname} = %{version}

%description pdf
NumPy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays.  NumPy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type which also makes NumPy suitable for
interfacing with general-purpose data-base applications.

There are also basic facilities for discrete fourier transform,
basic linear algebra and random number generation.

This package provides the PDF documentation for NumPy


%prep
%setup -q -n %{modname}-%{version}
%patch0 -p1
%patch1 -p1

%build
# make the documentation
cd doc 
make dist PYVER=%{py_ver}

%install
# install the documentation
cd doc
mkdir -p %{buildroot}%{_docdir}/python-%{modname}/{html,pdf}
tar -xzf build/dist.tar.gz -C %{buildroot}%{_docdir}/python-%{modname}/html
mv %{buildroot}%{_docdir}/python-%{modname}/html/*.pdf %{buildroot}%{_docdir}/python-%{modname}/pdf/

%fdupes %{buildroot}%{_docdir}/python-%{modname}/html/
%fdupes %{buildroot}%{_docdir}/python-%{modname}/pdf/

%files html
%defattr(-,root,root)
%{_docdir}/python-%{modname}/html/

%files pdf
%defattr(-,root,root)
%{_docdir}/python-%{modname}/pdf/

%changelog
* Tue Feb  4 2014 dvaleev@suse.com
- add numpy-double-double-le.patch for ppc64le
* Thu Oct 31 2013 toddrme2178@gmail.com
- Update to 1.8.0
  Highlights:
  * New, no 2to3, Python 2 and Python 3 are supported by a common code base.
  * New, gufuncs for linear algebra, enabling operations on stacked arrays.
  * New, inplace fancy indexing for ufuncs with the ``.at`` method.
  * New, ``partition`` function, partial sorting via selection for fast median.
  * New, ``nanmean``, ``nanvar``, and ``nanstd`` functions skipping NaNs.
  * New, ``full`` and ``full_like`` functions to create value initialized arrays.
  * New, ``PyUFunc_RegisterLoopForDescr``, better ufunc support for user dtypes.
  * Numerous performance improvements in many areas.
- Add a new flag to easily enable/disable atlas support for if it
  ever gets fixed in the future
- Rebase numpy-buildfix.patch
* Thu Aug  1 2013 speilicke@suse.com
- The *.egg-info is a file, not a directory
* Fri May  3 2013 toddrme2178@gmail.com
- Update to 1.7.1
  * Bugfixes
* Tue Mar 12 2013 highwaystar.ru@gmail.com
- update to 1.7.0
  * This release includes several new features as well as numerous
  bug fixes and refactorings
  Highlights:
  - ``where=`` parameter to ufuncs (allows the use of boolean
  arrays to choose where a computation should be done)
  - ``vectorize`` improvements (added 'excluded' and 'cache'
  keyword, general cleanup and bug fixes)
  - ``numpy.random.choice`` (random sample generating function)
  New Features:
  - Reduction UFuncs Generalize axis= Parameter
  - Reduction UFuncs New keepdims= Parameter
  - Datetime support
  - Custom formatter for printing arrays
  - New function numpy.random.choice
  - New function isclose
  - Preliminary multi-dimensional support in the polynomial package
  - Ability to pad rank-n arrays
  - New argument to searchsorted
  - Added experimental support for the AArch64 architecture.
  * For additional details check release notes at
  http://sourceforge.net/projects/numpy/files/NumPy/1.7.0/
- numpy-aarch64.diff: removed, now upstream
* Fri Jun  1 2012 toddrme2178@gmail.com
- Remove blas/lapack tests since these build successfully on all
  targets now
- Add documentation packages
  These are separate packages because a lot of packages depend on
  numpy, so building the documentation inside the base spec file
  would slow down the build process for the entire project
